==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebDropdownItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownItemDescription } from "./WebDropdownItemDescription";
/**
 * @hidden
 */
export let WebDropdownItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDropdownItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebDropdownItemDescriptionMetadata.a == null) {
                WebDropdownItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDropdownItemDescriptionMetadata.c(WebDropdownItemDescriptionMetadata.a);
            }
            if (a.j(WebDropdownItemDescriptionMetadata.a)) {
                return;
            }
            a.y(WebDropdownItemDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DropdownItem");
            a.item("__tagNameWC", "String:igc-dropdown-item");
            a.item("Value", "String");
            a.item("Selected", "Boolean");
            a.item("Active", "Boolean");
            a.item("Disabled", "Boolean");
        }
        static d(a) {
            WebDropdownItemDescriptionMetadata.b(a);
            a.aa("WebDropdownItem", () => new WebDropdownItemDescription());
            a.z("WebDropdownItem", WebDropdownItemDescriptionMetadata.a);
        }
    }
    WebDropdownItemDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDropdownItemDescriptionMetadata, 'WebDropdownItemDescriptionMetadata');
    WebDropdownItemDescriptionMetadata.a = null;
    return WebDropdownItemDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebDropdownItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownItemDescription } from "./WebDropdownItemDescription";
/**
 * @hidden
 */
export let WebDropdownItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDropdownItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebDropdownItemDescriptionMetadata.a == null) {
                WebDropdownItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDropdownItemDescriptionMetadata.c(WebDropdownItemDescriptionMetadata.a);
            }
            if (a.k(WebDropdownItemDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebDropdownItemDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DropdownItem");
            a.item("__tagNameWC", "String:igc-dropdown-item");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Value", "String");
            a.item("Selected", "Boolean");
            a.item("Active", "Boolean");
            a.item("Disabled", "Boolean");
        }
        static d(a) {
            WebDropdownItemDescriptionMetadata.b(a);
            a.ac("WebDropdownItem", () => new WebDropdownItemDescription());
            a.ab("WebDropdownItem", WebDropdownItemDescriptionMetadata.a);
        }
    }
    WebDropdownItemDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDropdownItemDescriptionMetadata, 'WebDropdownItemDescriptionMetadata');
    WebDropdownItemDescriptionMetadata.a = null;
    return WebDropdownItemDescriptionMetadata;
})();
